
****
Tips
****

Partially rasterized
====================

matplotlib has the possibility to make the saved image partly vector and partly rasterized.
To rasterize the output of the plot command use:

.. code-block:: python

    ax.plot(..., rasterized = True)
